==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/automation/kotlin/outputs/SUCSchedulePropertiesResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.automation.kotlin.outputs

import kotlin.Boolean
import kotlin.Double
import kotlin.String
import kotlin.Suppress

/**
 * Definition of schedule parameters.
 * @property advancedSchedule Gets or sets the advanced schedule.
 * @property creationTime Gets or sets the creation time.
 * @property description Gets or sets the description.
 * @property expiryTime Gets or sets the end time of the schedule.
 * @property expiryTimeOffsetMinutes Gets or sets the expiry time's offset in minutes.
 * @property frequency Gets or sets the frequency of the schedule.
 * @property interval Gets or sets the interval of the schedule.
 * @property isEnabled Gets or sets a value indicating whether this schedule is enabled.
 * @property lastModifiedTime Gets or sets the last modified time.
 * @property nextRun Gets or sets the next run time of the schedule.
 * @property nextRunOffsetMinutes Gets or sets the next run time's offset in minutes.
 * @property startTime Gets or sets the start time of the schedule.
 * @property startTimeOffsetMinutes Gets the start time's offset in minutes.
 * @property timeZone Gets or sets the time zone of the schedule.
 */
public data class SUCSchedulePropertiesResponse(
    public val advancedSchedule: AdvancedScheduleResponse? = null,
    public val creationTime: String? = null,
    public val description: String? = null,
    public val expiryTime: String? = null,
    public val expiryTimeOffsetMinutes: Double? = null,
    public val frequency: String? = null,
    public val interval: Double? = null,
    public val isEnabled: Boolean? = null,
    public val lastModifiedTime: String? = null,
    public val nextRun: String? = null,
    public val nextRunOffsetMinutes: Double? = null,
    public val startTime: String? = null,
    public val startTimeOffsetMinutes: Double,
    public val timeZone: String? = null,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.automation.outputs.SUCSchedulePropertiesResponse):
            SUCSchedulePropertiesResponse = SUCSchedulePropertiesResponse(
            advancedSchedule = javaType.advancedSchedule().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.automation.kotlin.outputs.AdvancedScheduleResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            creationTime = javaType.creationTime().map({ args0 -> args0 }).orElse(null),
            description = javaType.description().map({ args0 -> args0 }).orElse(null),
            expiryTime = javaType.expiryTime().map({ args0 -> args0 }).orElse(null),
            expiryTimeOffsetMinutes = javaType.expiryTimeOffsetMinutes().map({ args0 -> args0 }).orElse(null),
            frequency = javaType.frequency().map({ args0 -> args0 }).orElse(null),
            interval = javaType.interval().map({ args0 -> args0 }).orElse(null),
            isEnabled = javaType.isEnabled().map({ args0 -> args0 }).orElse(null),
            lastModifiedTime = javaType.lastModifiedTime().map({ args0 -> args0 }).orElse(null),
            nextRun = javaType.nextRun().map({ args0 -> args0 }).orElse(null),
            nextRunOffsetMinutes = javaType.nextRunOffsetMinutes().map({ args0 -> args0 }).orElse(null),
            startTime = javaType.startTime().map({ args0 -> args0 }).orElse(null),
            startTimeOffsetMinutes = javaType.startTimeOffsetMinutes(),
            timeZone = javaType.timeZone().map({ args0 -> args0 }).orElse(null),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/automation/kotlin/outputs/SUCSchedulePropertiesResponse.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.automation.kotlin.outputs

import kotlin.Boolean
import kotlin.Double
import kotlin.String
import kotlin.Suppress

/**
 * Definition of schedule parameters.
 * @property advancedSchedule Gets or sets the advanced schedule.
 * @property creationTime Gets or sets the creation time.
 * @property description Gets or sets the description.
 * @property expiryTime Gets or sets the end time of the schedule.
 * @property expiryTimeOffsetMinutes Gets or sets the expiry time's offset in minutes.
 * @property frequency Gets or sets the frequency of the schedule.
 * @property interval Gets or sets the interval of the schedule.
 * @property isEnabled Gets or sets a value indicating whether this schedule is enabled.
 * @property lastModifiedTime Gets or sets the last modified time.
 * @property nextRun Gets or sets the next run time of the schedule.
 * @property nextRunOffsetMinutes Gets or sets the next run time's offset in minutes.
 * @property startTime Gets or sets the start time of the schedule.
 * @property startTimeOffsetMinutes Gets the start time's offset in minutes.
 * @property timeZone Gets or sets the time zone of the schedule.
 */
public data class SUCSchedulePropertiesResponse(
    public val advancedSchedule: AdvancedScheduleResponse? = null,
    public val creationTime: String? = null,
    public val description: String? = null,
    public val expiryTime: String? = null,
    public val expiryTimeOffsetMinutes: Double? = null,
    public val frequency: String? = null,
    public val interval: Double? = null,
    public val isEnabled: Boolean? = null,
    public val lastModifiedTime: String? = null,
    public val nextRun: String? = null,
    public val nextRunOffsetMinutes: Double? = null,
    public val startTime: String? = null,
    public val startTimeOffsetMinutes: Double,
    public val timeZone: String? = null,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.automation.outputs.SUCSchedulePropertiesResponse): SUCSchedulePropertiesResponse = SUCSchedulePropertiesResponse(
            advancedSchedule = javaType.advancedSchedule().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.azurenative.automation.kotlin.outputs.AdvancedScheduleResponse.Companion.toKotlin(args0)
                })
            }).orElse(null),
            creationTime = javaType.creationTime().map({ args0 -> args0 }).orElse(null),
            description = javaType.description().map({ args0 -> args0 }).orElse(null),
            expiryTime = javaType.expiryTime().map({ args0 -> args0 }).orElse(null),
            expiryTimeOffsetMinutes = javaType.expiryTimeOffsetMinutes().map({ args0 -> args0 }).orElse(null),
            frequency = javaType.frequency().map({ args0 -> args0 }).orElse(null),
            interval = javaType.interval().map({ args0 -> args0 }).orElse(null),
            isEnabled = javaType.isEnabled().map({ args0 -> args0 }).orElse(null),
            lastModifiedTime = javaType.lastModifiedTime().map({ args0 -> args0 }).orElse(null),
            nextRun = javaType.nextRun().map({ args0 -> args0 }).orElse(null),
            nextRunOffsetMinutes = javaType.nextRunOffsetMinutes().map({ args0 -> args0 }).orElse(null),
            startTime = javaType.startTime().map({ args0 -> args0 }).orElse(null),
            startTimeOffsetMinutes = javaType.startTimeOffsetMinutes(),
            timeZone = javaType.timeZone().map({ args0 -> args0 }).orElse(null),
        )
    }
}
